@@ -43,7 +43,6 @@
 #' model <- lavaan::sem(structure, data = PoliticalDemocracy)
 #' model_parameters(model)
 #' model_parameters(model, standardize = TRUE)
-#'
 #' \donttest{
 #' # blavaan ------------------------------------
 #' # library(blavaan)
@@ -76,56 +75,6 @@ model_parameters.lavaan <- function(model, ci = 0.95, standardize = FALSE, type
 }
 
 
-#' @keywords internal
-.extract_parameters_lavaan <- function(model, ci = 0.95, standardize = FALSE, ...) {
-  if (!requireNamespace("lavaan", quietly = TRUE)) {
-    stop("Package 'lavaan' required for this function to work. Please install it by running `install.packages('lavaan')`.")
-  }
-
-  # CI
-  if (length(ci) > 1) {
-    ci <- ci[1]
-    warning(paste0("lavaan models only accept one level of CI :( Keeping the first one: `ci = ", ci, "`."))
-  }
-
-  # Get estimates
-  if (standardize == FALSE) {
-    data <- lavaan::parameterEstimates(model, se = TRUE, level = ci, ...)
-  } else {
-    data <- lavaan::standardizedsolution(model, se = TRUE, level = ci, ...)
-    names(data)[names(data) == "est.std"] <- "est"
-  }
-
-
-
-  params <- data.frame(
-    To = data$lhs,
-    Operator = data$op,
-    From = data$rhs,
-    Coefficient = data$est,
-    SE = data$se,
-    CI_low = data$ci.lower,
-    CI_high = data$ci.upper,
-    p = data$pvalue
-  )
-
-  params$Type <- ifelse(params$Operator == "=~", "Loading",
-    ifelse(params$Operator == "~", "Regression",
-      ifelse(params$Operator == "~~", "Correlation",
-        ifelse(params$Operator == "~1", "Mean", NA)
-      )
-    )
-  )
-  params$Type <- ifelse(as.character(params$From) == as.character(params$To), "Variance", params$Type)
-  params$p <- ifelse(is.na(params$p), 0, params$p)
-
-  if ("group" %in% names(data)) {
-    params$Group <- data$group
-  }
-
-  params
-}
-
 
 #' @export
 n_parameters.lavaan <- function(x, ...) {
@@ -136,10 +85,12 @@ n_parameters.lavaan <- function(x, ...) {
 }
 
 
+#' @importFrom insight format_table
 #' @export
 print.parameters_sem <- function(x, ...) {
-  formatted_table <- parameters_table(x)
-  cat(format_table(formatted_table))
+  # formatted_table <- parameters_table(x)
+  # cat(insight::format_table(formatted_table))
+  .print_model_parms_components(x, pretty_names = TRUE, split_column = "Type")
 }
 
 
