@@ -18,6 +18,9 @@
 #'
 #' @return A data.frame.
 #'
+#' @importFrom tools toTitleCase
+#' @importFrom insight format_value
+#' @importFrom stats na.omit
 #' @export
 parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, ...) {
   x <- as.data.frame(x)
@@ -28,20 +31,31 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, ...) {
   }
 
   # Format specific columns
-  if ("n_Obs" %in% names(x)) x$n_Obs <- format_value(x$n_Obs, protect_integers = TRUE)
-  if ("n_Missing" %in% names(x)) x$n_Missing <- format_value(x$n_Missing, protect_integers = TRUE)
-  if ("df" %in% names(x)) x$df <- format_value(x$df, protect_integers = TRUE)
-  if ("df_residual" %in% names(x)) x$df_residual <- format_value(x$df_residual, protect_integers = TRUE)
+  if ("n_Obs" %in% names(x)) x$n_Obs <- insight::format_value(x$n_Obs, protect_integers = TRUE)
+  if ("n_Missing" %in% names(x)) x$n_Missing <- insight::format_value(x$n_Missing, protect_integers = TRUE)
+  if ("df" %in% names(x)) x$df <- insight::format_value(x$df, protect_integers = TRUE)
+  if ("df_residual" %in% names(x)) x$df_residual <- insight::format_value(x$df_residual, protect_integers = TRUE)
   names(x)[names(x) == "df_residual"] <- "df"
-  if ("p" %in% names(x)) x$p <- format_p(x$p, name = NULL, stars = stars)
+
+  # P values
+  if ("p" %in% names(x)) {
+    x$p <- format_p(x$p, stars = stars, name = NULL, missing = "")
+    x$p <- format(x$p, justify = "left")
+  }
 
   # CI
   ci_low <- names(x)[grep("CI_low*", names(x))]
   ci_high <- names(x)[grep("CI_high*", names(x))]
   if (length(ci_low) >= 1 & length(ci_low) == length(ci_high)) {
-    ci_colname <- sprintf("%i%% CI", attributes(x)$ci * 100)
+    if (is.null(attributes(x)$ci)) {
+      ci_colname <- "CI"
+    } else {
+      ci_colname <- sprintf("%i%% CI", attributes(x)$ci * 100)
+    }
+    # Get characters to align the CI
+    max_len <- max(nchar(stats::na.omit(c(round(x[[ci_low]], 2), round(x[[ci_high]], 2)))))
     for (i in 1:length(ci_colname)) {
-      x[ci_colname[i]] <- format_ci(x[[ci_low[i]]], x[[ci_high[i]]], ci = NULL)
+      x[ci_colname[i]] <- format_ci(x[[ci_low[i]]], x[[ci_high[i]]], ci = NULL, width = max_len, brackets = TRUE)
     }
     # Replace at initial position
     ci_position <- which(names(x) == ci_low[1])
@@ -51,16 +65,16 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, ...) {
 
   # Standardized
   std_cols <- names(x)[grepl("Std_", names(x))]
-  x[std_cols] <- format_value(x[std_cols])
+  x[std_cols] <- insight::format_value(x[std_cols])
   names(x)[grepl("Std_", names(x))] <- paste0(gsub("Std_", "", std_cols), " (std.)")
 
   # Partial
-  x[names(x)[grepl("_partial", names(x))]] <- format_value(x[names(x)[grepl("_partial", names(x))]])
+  x[names(x)[grepl("_partial", names(x))]] <- insight::format_value(x[names(x)[grepl("_partial", names(x))]])
   names(x)[grepl("_partial", names(x))] <- paste0(gsub("_partial", "", names(x)[grepl("_partial", names(x))]), " (partial)")
 
   # Bayesian
-  if ("Prior_Location" %in% names(x)) x$Prior_Location <- format_value(x$Prior_Location, protect_integers = TRUE)
-  if ("Prior_Scale" %in% names(x)) x$Prior_Scale <- format_value(x$Prior_Scale, protect_integers = TRUE)
+  if ("Prior_Location" %in% names(x)) x$Prior_Location <- insight::format_value(x$Prior_Location, protect_integers = TRUE)
+  if ("Prior_Scale" %in% names(x)) x$Prior_Scale <- insight::format_value(x$Prior_Scale, protect_integers = TRUE)
   if ("BF" %in% names(x)) x$BF <- format_bf(x$BF, name = NULL, stars = stars)
   if ("pd" %in% names(x)) x$pd <- format_pd(x$pd, name = NULL, stars = stars)
   if ("ROPE_Percentage" %in% names(x)) x$ROPE_Percentage <- format_rope(x$ROPE_Percentage, name = NULL)
@@ -82,12 +96,12 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, ...) {
     x$Prior_Distribution <- x$Prior_Location <- x$Prior_Scale <- NULL
   }
 
-  if ("Rhat" %in% names(x)) x$Rhat <- format_value(x$Rhat, digits = 3)
-  if ("ESS" %in% names(x)) x$ESS <- format_value(x$ESS, protect_integers = TRUE)
+  if ("Rhat" %in% names(x)) x$Rhat <- insight::format_value(x$Rhat, digits = 3)
+  if ("ESS" %in% names(x)) x$ESS <- insight::format_value(x$ESS, protect_integers = TRUE)
 
   # Format remaining columns
   other_cols <- names(x)[sapply(x, is.numeric)]
-  x[other_cols[other_cols %in% names(x)]] <- format_value(x[other_cols[other_cols %in% names(x)]])
+  x[other_cols[other_cols %in% names(x)]] <- insight::format_value(x[other_cols[other_cols %in% names(x)]])
 
 
   # SEM links
@@ -101,11 +115,3 @@ parameters_table <- function(x, pretty_names = TRUE, stars = FALSE, ...) {
 
   x
 }
-
-
-
-#' @export
-print.parameters_model <- function(x, pretty_names = TRUE, ...) {
-  formatted_table <- parameters_table(x, pretty_names = pretty_names, ...)
-  cat(format_table(formatted_table))
-}
