@@ -1,60 +1,66 @@
-#' @export
-sort.parameters_efa <- function(x, ...) {
-  .sort_loadings(x)
-}
+# summary -----------------------------------------------------------------
+
+
 
-#' @export
-sort.parameters_pca <- sort.parameters_efa
 
 #' @export
 summary.parameters_efa <- function(object, ...) {
-  insight::print_color("# (Explained) Variance of Principal Components\n\n", "blue")
-
   x <- attributes(object)$summary
-  x$Variance_Explained <- x$Variance / sum(x$Variance)
-  x$Std_Dev <- attributes(object)$model$sdev
-
-  col_names <- x$Component
 
   cols <- intersect(
-    c("Std_Dev", "Eigenvalues", "Variance", "Variance_Cumulative", "Variance_Explained"),
+    c("Std_Dev", "Eigenvalues", "Variance", "Variance_Cumulative", "Variance_Proportion"),
     colnames(x)
   )
 
-  rows <- c("Eigenvalues", "Variance", "Cumulative Variance", "Explained Variance")
-  if ("Std_Dev" %in% cols) rows <- c("Standard Deviation", rows)
 
   x <- as.data.frame(t(x[, cols]))
-  x <- cbind(data.frame("Values" = rows, stringsAsFactors = FALSE), x)
+  x <- cbind(data.frame("Parameter" = row.names(x), stringsAsFactors = FALSE), x)
+  names(x) <- c("Parameter", attributes(object)$summary$Component)
+  row.names(x) <- NULL
 
-  colnames(x) <- c("", col_names)
-  class(x) <- c("parameters_efa_summary", class(x))
+  if ("parameters_efa" %in% class(object)) {
+    class(x) <- c("parameters_efa_summary", class(object))
+  } else {
+    class(x) <- c("parameters_pca_summary", class(object))
+  }
   x
 }
 
-#' @export
-print.parameters_efa_summary <- function(x, digits = 3, ...) {
-  cat(format_table(x, digits = digits, ...))
-
-  invisible(x)
-}
-
 #' @export
 summary.parameters_pca <- summary.parameters_efa
 
 
 
-
 #' @export
 model_parameters.parameters_efa <- function(model, ...) {
-  attributes(model)$summary
+  x <- attributes(model)$summary
+
+  if ("parameters_efa" %in% class(model)) {
+    class(x) <- c("parameters_efa_summary", class(model))
+  } else {
+    class(x) <- c("parameters_pca_summary", class(model))
+  }
+  x
 }
+
 #' @export
 model_parameters.parameters_pca <- model_parameters.parameters_efa
 
 
 
 
+
+
+
+
+
+
+
+
+# predict -----------------------------------------------------------------
+
+
+
 #' @export
 predict.parameters_efa <- function(object, newdata = NULL, names = NULL, ...) {
   if (is.null(newdata)) {
@@ -74,12 +80,41 @@ predict.parameters_pca <- predict.parameters_efa
 
 
 
+
+
+
+# print -------------------------------------------------------------------
+
+
+#' @importFrom insight format_table
+#' @export
+print.parameters_efa_summary <- function(x, digits = 3, ...) {
+  insight::print_color("# (Explained) Variance of Components\n\n", "blue")
+
+  if ("Parameter" %in% names(x)) {
+    x$Parameter <- c("Eigenvalues", "Variance Explained", "Variance Explained (Cumulative)", "Variance Explained (Proportion)")
+  } else if ("Component" %in% names(x)) {
+    names(x) <- c("Copmponent", "Eigenvalues", "Variance Explained", "Variance Explained (Cumulative)", "Variance Explained (Proportion)")
+  }
+
+  cat(insight::format_table(x, digits = digits, ...))
+
+  invisible(x)
+}
+
+#' @export
+print.parameters_pca_summary <- print.parameters_efa_summary
+
+
+
+
+
 #' @importFrom insight print_color print_colour
 #' @export
 print.parameters_efa <- function(x, digits = 2, sort = FALSE, threshold = NULL, labels = NULL, ...) {
 
   # Labels
-  if(!is.null(labels)){
+  if (!is.null(labels)) {
     x$Label <- labels
     x <- x[c("Variable", "Label", names(x)[!names(x) %in% c("Variable", "Label")])]
   }
@@ -91,26 +126,27 @@ print.parameters_efa <- function(x, digits = 2, sort = FALSE, threshold = NULL,
 
   # Replace by NA all cells below threshold
   if (!is.null(threshold)) {
-    x <- .filer_loadings(x, threshold = threshold)
+    x <- .filter_loadings(x, threshold = threshold)
   }
 
 
 
-  .rotation <- attr(x, "rotation", exact = TRUE)
+  rotation_name <- attr(x, "rotation", exact = TRUE)
 
-  if (.rotation == "none") {
+  if (rotation_name == "none") {
     insight::print_color("# Loadings from Principal Component Analysis (no rotation)\n\n", "blue")
   } else {
-    insight::print_color(sprintf("# Rotated loadings from Principal Component Analysis (%s-rotation)\n\n", .rotation), "blue")
+    insight::print_color(sprintf("# Rotated loadings from Principal Component Analysis (%s-rotation)\n\n", rotation_name), "blue")
   }
 
-  cat(format_table(x, digits = digits, ...))
+  cat(insight::format_table(x, digits = digits, ...))
 
   if (!is.null(attributes(x)$type)) {
     cat("\n")
     insight::print_colour(.text_components_variance(x), "yellow")
   }
 }
+
 #' @export
 print.parameters_pca <- print.parameters_efa
 
@@ -118,23 +154,11 @@ print.parameters_pca <- print.parameters_efa
 
 
 
-#' @export
-principal_components.lm <- function(x, ...) {
-  principal_components(insight::get_predictors(x, ...), ...)
-}
-
-#' @export
-principal_components.merMod <- principal_components.lm
-
-
-
-
-
 
 #' @keywords internal
 .text_components_variance <- function(x) {
   type <- attributes(x)$type
-  if (type %in% c("prcomp", "principal")) {
+  if (type %in% c("prcomp", "principal", "pca")) {
     type <- "principal component"
   } else if (type %in% c("fa")) {
     type <- "latent factor"
@@ -185,6 +209,18 @@ principal_components.merMod <- principal_components.lm
 
 
 
+# sort --------------------------------------------------------------------
+
+
+#' @export
+sort.parameters_efa <- function(x, ...) {
+  .sort_loadings(x)
+}
+
+#' @export
+sort.parameters_pca <- sort.parameters_efa
+
+
 
 
 #' @keywords internal
@@ -232,3 +268,31 @@ principal_components.merMod <- principal_components.lm
 
   loadings
 }
+
+# Filter --------------------------------------------------------------------
+
+
+#' @keywords internal
+.filter_loadings <- function(loadings, threshold = 0.2, loadings_columns = NULL) {
+  if (is.null(loadings_columns)) {
+    loadings_columns <- attributes(loadings)$loadings_columns
+  }
+
+
+  if (threshold == "max" | threshold >= 1) {
+    if (threshold == "max") {
+      for (row in 1:nrow(loadings)) {
+        maxi <- max(abs(loadings[row, loadings_columns, drop = FALSE]))
+        loadings[row, loadings_columns][abs(loadings[row, loadings_columns]) < maxi] <- NA
+      }
+    } else {
+      for (col in loadings_columns) {
+        loadings[tail(order(abs(loadings[, col]), decreasing = TRUE), -round(threshold)), col] <- NA
+      }
+    }
+  } else {
+    loadings[, loadings_columns][abs(loadings[, loadings_columns]) < threshold] <- NA
+  }
+
+  loadings
+}
