@@ -13,13 +13,6 @@ test_that("format_p", {
   testthat::expect_equal(nchar(format_p(0.02, stars_only = TRUE)), 1)
 })
 
-test_that("format_value", {
-  testthat::expect_equal(nchar(format_value(1.2012313)), 4)
-  testthat::expect_true(is.int(2))
-  testthat::expect_equal(nchar(format_value(4.2, protect_integers = TRUE)), 4)
-  testthat::expect_equal(nchar(format_value(4.0, protect_integers = TRUE)), 1)
-})
-
 test_that("format_number and format_order", {
   testthat::expect_equal(format_number(2), "two")
   testthat::expect_equal(format_number(45), "forty five")
